
From: Frank Sorenson <frank@tuxrocks.com>

The stack randomization patches that went into 2.6.11-rc3-mm1 broke
compilation of ARCH=um.  This patch fixes compiling by adding
arch_align_stack back in.

Signed-off-by: Frank Sorenson <frank@tuxrocks.com>
Acked-By: Jeff Dike <jdike@addtoit.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/arch/um/kernel/process_kern.c |    9 +++++++++
 1 files changed, 9 insertions(+)

diff -puN arch/um/kernel/process_kern.c~fix-compilation-of-uml-after-the-stack-randomization-patches arch/um/kernel/process_kern.c
--- 25/arch/um/kernel/process_kern.c~fix-compilation-of-uml-after-the-stack-randomization-patches	2005-02-04 12:52:23.196003424 -0800
+++ 25-akpm/arch/um/kernel/process_kern.c	2005-02-04 12:52:23.201002664 -0800
@@ -21,6 +21,7 @@
 #include "linux/spinlock.h"
 #include "linux/proc_fs.h"
 #include "linux/ptrace.h"
+#include "linux/random.h"
 #include "asm/unistd.h"
 #include "asm/mman.h"
 #include "asm/segment.h"
@@ -479,6 +480,14 @@ int singlestepping(void * t)
 	return 2;
 }
 
+unsigned long arch_align_stack(unsigned long sp)
+{
+	if (randomize_va_space)
+		sp -= get_random_int() % 8192;
+	return sp & ~0xf;
+}
+
+
 /*
  * Overrides for Emacs so that we follow Linus's tabbing style.
  * Emacs will notice this stuff at the end of the file and automatically
_
